@@ -863,9 +863,11 @@ aft_dmachain_enable_tdmv_and_mtu_size(u32 *reg, int size)
 #define AFT_SERIAL_LCFG_X21_MODE_BIT	6
 
 #define AFT_SERIAL_LCFG_BAUD_SHIFT	8
-#define AFT_SERIAL_LCFG_BAUD_MASK	0xFFFF
+#define AFT_SERIAL_LCFG_BAUD_ORIG_MASK	0xFFFF
+#define AFT_SERIAL_LCFG_BAUD_MASK	0xFFF
 
-#define AFT_SERIAL_LCFG_CLK_SRC_BIT	24
+#define AFT_SERIAL_LCFG_CLK_OSC_SEL_BIT	23
+#define AFT_SERIAL_LCFG_CLK_SRC_BIT		24
 #define AFT_SERIAL_LCFG_CTS_INTR_EN_BIT	25
 #define AFT_SERIAL_LCFG_DCD_INTR_EN_BIT 26
 #define AFT_SERIAL_LCFG_IDLE_DET_BIT	27
@@ -875,17 +877,147 @@ aft_dmachain_enable_tdmv_and_mtu_size(u32 *reg, int size)
 
 #define AFT_SERIAL_LCFG_IFACE_TYPE_BIT	31
 
-static __inline void
-aft_serial_set_baud_rate(u32 *reg, u32 rate)
+static __inline int
+aft_serial_set_legacy_baud_rate(u32 *reg, u32 rate)
 {
-	u32 div= (14745600/(2*rate));
-	u32 remain= (14745600%(2*rate));
-	if (!remain || (remain/2 > rate)) {
-		div=div-1;	
+	u32 div,remain;
+
+	div=14745600/(2*rate);
+        remain=14745600%(2*rate);
+        if (remain > rate) {
+                div=div+1;
+        }
+        if (div > 0) {
+                div=div-1;
+        }
+
+	if (div==0) {
+		DEBUG_EVENT("wanpipe: Error: Baud Rate Requested %i too high! Cannot be generated by hardware!\n",
+				rate);
+		return -1;
 	}
+
+	*reg&=~(AFT_SERIAL_LCFG_BAUD_ORIG_MASK<<AFT_SERIAL_LCFG_BAUD_SHIFT);
+	*reg|= ((div)&AFT_SERIAL_LCFG_BAUD_ORIG_MASK)<<AFT_SERIAL_LCFG_BAUD_SHIFT;
+
+	wan_clear_bit(AFT_SERIAL_LCFG_CLK_OSC_SEL_BIT,&reg);
+	
+	return 0;
+}
+
+static __inline int
+aft_serial_set_baud_rate(u32 *reg, u32 rate, u32 recovery)
+{
+	u32 div,remain,freq,percent;
+	u32 acc1,acc2,div1,div2,round1,round2;
+
+	round1=round2=0;
+
+	if (rate == 0) {
+		return -1;
+	}
+
+	div=14745600/(2*rate);
+	remain=14745600%(2*rate);
+	DEBUG_TEST("DIV=%u REMAIN1 %u  rate=%u\n",div,remain,rate);
+	if (remain > rate) {
+		div=div+1;	
+		round1=1;
+	}
+	if (div > 0) {
+		div=div-1;
+	}
+	div1=div;
+
+	if (remain > rate) {
+		acc1= 2*rate - remain;
+	} else {
+		acc1=remain;
+	}
+
+	div=(12352000)/(2*rate);
+	remain=(12352000)%(2*rate);
+	DEBUG_TEST("DIV=%u REMAIN2 %u  rate=%u\n",div,remain,rate);
+	if (remain > rate) {
+		div=div+1;
+		round2=1;
+	}
+
+	if (div > 0) {
+		div=div-1;
+	}
+	div2=div;
+
+	if (remain > rate) {
+		acc2= 2*rate - remain;
+	} else {
+		acc2=remain;
+	}
+
+	if (acc1 > acc2) {
+		wan_set_bit(AFT_SERIAL_LCFG_CLK_OSC_SEL_BIT,reg); 
+		div=div2;
+	
+		if (div == 0) {
+			DEBUG_EVENT("wanpipe: Error: Baud Rate Requested %i too high! Cannot be generated by hardware!\n",
+					recovery?rate/32:rate);
+			return -1;
+		}
+
+		DEBUG_EVENT("NEW OSC: DIV=%i (DIV1=%i DIV2=%i) (ACC1=%i ACC2=%i)\n",div,div1,div2,acc1,acc2);
+		freq=12352000/(2*(div+round2+1));
+		percent=abs(freq-rate)*100/rate;
+
+		if (recovery) {
+			freq=freq/32;
+			rate=rate/32;
+		}
+		
+		if (percent > 2) {
+			DEBUG_EVENT("wanpipe: Error: Baud Rate Requested %i cannot be generated by hardware! Actual=%i Tolerance=%i\n",
+				rate,freq,percent);
+			return -EINVAL;
+		}
+		
+		DEBUG_EVENT("wanpipe: Baud Rate Requested %i, Baud Rate Generated %i, Tolerance=%i\n",rate,freq,percent);
+	} else {
+		wan_clear_bit(AFT_SERIAL_LCFG_CLK_OSC_SEL_BIT,reg);
+		div=div1;
+	
+		if (div == 0) {
+			DEBUG_EVENT("wanpipe: Error: Baud Rate Requested %i too high! Cannot be generated by hardware!\n",
+					recovery?rate/32:rate);
+			return -1;
+		}
+
+		DEBUG_EVENT("ORIG OSC: DIV=%i (DIV1=%i DIV2=%i) (ACC1=%i ACC2=%i)\n",div,div1,div2,acc1,acc2);
+		freq=14745600/(2*(div+round1+1));
+		percent=abs(freq-rate)*100/rate;
+	
+               if (recovery) {
+                        freq=freq/32;
+                        rate=rate/32;
+                }
+
+                if (percent > 2) {
+			DEBUG_EVENT("wanpipe: Error: Baud Rate Requested %i cannot be generated by hardware! Actual=%i Tolerance=%i\n",
+					rate,freq,percent);
+                        return -EINVAL;
+                }
+
+		DEBUG_EVENT("wanpipe: Baud Rate Requested %i, Baud Rate Generated %i, Tolerance=%i\n",
+				rate,freq,percent);
+	}
+
+		
 	*reg&=~(AFT_SERIAL_LCFG_BAUD_MASK<<AFT_SERIAL_LCFG_BAUD_SHIFT);
 	*reg|= ((div)&AFT_SERIAL_LCFG_BAUD_MASK)<<AFT_SERIAL_LCFG_BAUD_SHIFT;
+	DEBUG_EVENT(" OSC: DIV=%i REG=0x%08X \n",div,*reg);
+
+	return 0;
+
 }
+
 static __inline void
 aft_serial_set_lcoding(u32 *reg, u32 coding)
 {
