@@ -47,6 +47,9 @@
 #define __wan_skb_set_tail_pointer(skb,offset) ((skb)->tail = ((skb)->data + offset))
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,23)
+#define	cancel_work_sync(work) ({ cancel_work_sync(work); 0; })
+#endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,24) || defined(LINUX_FEAT_2624)
 # ifndef LINUX_FEAT_2624
