@@ -2178,6 +2178,12 @@ static wanpipe_tdm_api_dev_t *wp_tdmapi_search(sdla_t *card, int fe_chan)
 		}
 		
 		if (IS_BRI_CARD(card)) {
+			/* BRI - d-channel does not have a bit mask in tdm_api->active_ch,
+				but channel 3 is still a valid event */
+			if (fe_chan == 3) {
+				return tdm_api;
+			}
+
 			tmp_fe_chan = (2*(tdm_api->tdm_span-1))+fe_chan;
 		} 	
 
