@@ -1175,6 +1175,7 @@ int AFTUsage(void)
 	printf("\t             ddlb3   Deactive Digital Loopback mode (DS3/E3 cards)\n");  
 	printf("\t             txe     Enable TX (AFT card only)\n");  
 	printf("\t             txd     Disable TX (AFT card only)\n");  
+	printf("\t             bert    T1/E1 BERT test (T1/E1 DM cards only)\n");  
 	printf("\tFlush Statistics\n");
 	printf("\t   f         c       Flush Communication Error Statistics\n");
 	printf("\t             o       Flush Operational Statistics\n");
@@ -1253,7 +1254,7 @@ static void read_ft1_te1_56k_config (void)
 int AFTMain(char *command,int argc, char* argv[])
 {
 	char		*opt=&command[1];
-	int		mod_no = 0, i, err;
+	int		mod_no = 0, i, err = 0;
 	sdla_fe_debug_t	fe_debug;
 			
 	switch(command[0]){
@@ -1349,9 +1350,9 @@ int AFTMain(char *command,int argc, char* argv[])
 			}else if (!strcmp(opt,"ddlb")){
 				set_lb_modes(WAN_TE1_DDLB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"salb")){
-				set_lb_modes(WAN_TE1_TX_LB_MODE, WAN_TE1_LB_ENABLE);
+				set_lb_modes(WAN_TE1_TX_LINELB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"sdlb")){
-				set_lb_modes(WAN_TE1_TX_LB_MODE, WAN_TE1_LB_DISABLE);
+				set_lb_modes(WAN_TE1_TX_LINELB_MODE, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"alalb")){
 				set_lb_modes(WAN_TE1_LIU_ALB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dlalb")){
@@ -1388,6 +1389,8 @@ int AFTMain(char *command,int argc, char* argv[])
 				set_fe_tx_mode(WAN_FE_TXMODE_ENABLE);
 			}else if (!strcmp(opt,"txd")){
 				set_fe_tx_mode(WAN_FE_TXMODE_DISABLE);
+			}else if (!strcmp(opt,"bert")){
+				err = set_fe_bert(argc, argv);
 			}else{
 				printf("ERROR: Invalid FT1 Command 'T', Type wanpipemon <cr> for help\n\n");
 			} 
@@ -1556,5 +1559,5 @@ int AFTMain(char *command,int argc, char* argv[])
 	}//switch 
    	printf("\n");
    	fflush(stdout);
-   	return 0;
+   	return err;
 }; //main
